import path from "path";
import { fileURLToPath } from "url";
// import pkg from "./package.json" assert { type: "json" };
import ProgressPlugin from "progress-webpack-plugin";
import CopyWebpackPlugin from "copy-webpack-plugin";

const __dirname = path.dirname(fileURLToPath(new URL(import.meta.url)));

export default {
  entry: "./index.tsx",
  mode: "production",
  target: "web",
  resolve: {
    extensions: [".js", ".json", ".wasm", ".ts", ".tsx", ".jsx"],
  },
  externals: {
    'react': 'React'
  },
  module: {
    rules: [
      {
        test: /\.(ts|js)x?$/,
        exclude: /node_modules/,
        use: {
          loader: "babel-loader"
        },
      }, {
        test: /\.css$/i,
        use: ["style-loader", "css-loader", "postcss-loader"],
      }
    ],
  },
  plugins: [
    new ProgressPlugin(true),
    new CopyWebpackPlugin({
      patterns: [{ from: "dapp.yml" }],
    }),
  ],
  output: {
    publicPath: '',
    filename: "main.js",
    path: path.resolve(__dirname, ".cpchain/.dapp"),
    clean: true,
    library: "main",
    libraryExport: "default",
  },
  watchOptions: {
    ignored: ["tmp", "templates", "dist", "runtimes"],
  },
};
